@@ -1,6 +1,6 @@
 /* Handle shared libraries for GDB, the GNU Debugger.
 
-   Copyright (C) 2009-2019 Free Software Foundation, Inc.
+   Copyright (C) 2009-2024 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -17,12 +17,11 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef SOLIB_DARWIN_H
-#define SOLIB_DARWIN_H
+#ifndef GDB_SOLIB_DARWIN_H
+#define GDB_SOLIB_DARWIN_H
 
-struct objfile;
-struct target_so_ops;
+struct solib_ops;
 
-extern struct target_so_ops darwin_so_ops;
+extern const solib_ops darwin_so_ops;
 
-#endif /* solib-darwin.h */
+#endif /* GDB_SOLIB_DARWIN_H */
